@@ -141,7 +141,7 @@ filename='plot.png', marker='x', grid=True)
         return _available
 
     def __call__(self, manager):
-        if self.available():
+        if _available:
             # Dynamically import pyplot to call matplotlib.use()
             # after importing pytorch_pfn_extras.training.extensions
             import matplotlib.pyplot as plt
